pandeia.engine package
======================

Subpackages
-----------

.. toctree::

    pandeia.engine.defaults
..    pandeia.engine.helpers

Submodules
----------

pandeia.engine.astro_spectrum module
------------------------------------

.. automodule:: pandeia.engine.astro_spectrum
    :members:
    :undoc-members:
    :show-inheritance:

pandeia.engine.background module
--------------------------------

.. automodule:: pandeia.engine.background
    :members:
    :undoc-members:
    :show-inheritance:

pandeia.engine.bnc module
-------------------------

.. automodule:: pandeia.engine.bnc
    :members:
    :undoc-members:
    :show-inheritance:

pandeia.engine.calc_utils module
--------------------------------

.. automodule:: pandeia.engine.calc_utils
    :members:
    :undoc-members:
    :show-inheritance:

pandeia.engine.config module
----------------------------

.. automodule:: pandeia.engine.config
    :members:
    :undoc-members:
    :show-inheritance:

pandeia.engine.constants module
-------------------------------

.. automodule:: pandeia.engine.constants
    :members:
    :undoc-members:
    :show-inheritance:

pandeia.engine.coords module
----------------------------

.. automodule:: pandeia.engine.coords
    :members:
    :undoc-members:
    :show-inheritance:

pandeia.engine.custom_exceptions module
---------------------------------------

.. automodule:: pandeia.engine.custom_exceptions
    :members:
    :undoc-members:
    :show-inheritance:

pandeia.engine.etc3D module
---------------------------

.. automodule:: pandeia.engine.etc3D
    :members:
    :undoc-members:
    :show-inheritance:

pandeia.engine.exposure module
------------------------------

.. automodule:: pandeia.engine.exposure
    :members:
    :undoc-members:
    :show-inheritance:

pandeia.engine.extinction module
--------------------------------

.. automodule:: pandeia.engine.extinction
    :members:
    :undoc-members:
    :show-inheritance:

pandeia.engine.hst module
-------------------------

.. automodule:: pandeia.engine.hst
    :members:
    :undoc-members:
    :show-inheritance:

pandeia.engine.instrument module
--------------------------------

.. automodule:: pandeia.engine.instrument
    :members:
    :undoc-members:
    :show-inheritance:

pandeia.engine.instrument_factory module
----------------------------------------

.. automodule:: pandeia.engine.instrument_factory
    :members:
    :undoc-members:
    :show-inheritance:

pandeia.engine.io_utils module
------------------------------

.. automodule:: pandeia.engine.io_utils
    :members:
    :undoc-members:
    :show-inheritance:

pandeia.engine.jwst module
--------------------------

.. automodule:: pandeia.engine.jwst
    :members:
    :undoc-members:
    :show-inheritance:

pandeia.engine.nb_utils module
------------------------------

.. automodule:: pandeia.engine.nb_utils
    :members:
    :undoc-members:
    :show-inheritance:

pandeia.engine.normalization module
-----------------------------------

.. automodule:: pandeia.engine.normalization
    :members:
    :undoc-members:
    :show-inheritance:

pandeia.engine.observation module
---------------------------------

.. automodule:: pandeia.engine.observation
    :members:
    :undoc-members:
    :show-inheritance:

pandeia.engine.pandeia_warnings module
--------------------------------------

.. automodule:: pandeia.engine.pandeia_warnings
    :members:
    :undoc-members:
    :show-inheritance:

pandeia.engine.profile module
-----------------------------------------

.. automodule:: pandeia.engine.profile
    :members:
    :undoc-members:
    :show-inheritance:

pandeia.engine.projection module
---------------------------------

.. automodule:: pandeia.engine.projection
    :members:
    :undoc-members:
    :show-inheritance:

pandeia.engine.perform_calculation module
-----------------------------------------

.. automodule:: pandeia.engine.perform_calculation
    :members:
    :undoc-members:
    :show-inheritance:

pandeia.engine.psf_library module
---------------------------------

.. automodule:: pandeia.engine.psf_library
    :members:
    :undoc-members:
    :show-inheritance:

pandeia.engine.report module
----------------------------

.. automodule:: pandeia.engine.report
    :members:
    :undoc-members:
    :show-inheritance:

pandeia.engine.scene module
---------------------------

.. automodule:: pandeia.engine.scene
    :members:
    :undoc-members:
    :show-inheritance:

pandeia.engine.sed module
-------------------------

.. automodule:: pandeia.engine.sed
    :members:
    :undoc-members:
    :show-inheritance:

pandeia.engine.source module
----------------------------

.. automodule:: pandeia.engine.source
    :members:
    :undoc-members:
    :show-inheritance:

pandeia.engine.strategy module
------------------------------

.. automodule:: pandeia.engine.strategy
    :members:
    :undoc-members:
    :show-inheritance:

pandeia.engine.telescope module
-------------------------------

.. automodule:: pandeia.engine.telescope
    :members:
    :undoc-members:
    :show-inheritance:

pandeia.engine.utils module
---------------------------

.. automodule:: pandeia.engine.utils
    :members:
    :undoc-members:
    :show-inheritance:

pandeia.engine.roman module
----------------------------

.. automodule:: pandeia.engine.roman
    :members:
    :undoc-members:
    :show-inheritance:


Module contents
---------------

.. automodule:: pandeia.engine
    :members:
    :undoc-members:
    :show-inheritance:
